@@ -180,7 +180,7 @@ cantCodeCheckMessage <- ": line could not be checked "
       } else if (identical(x[[1]], quote(`<-`)) ) {
         if (length(x[[2]]) > 1) {
           if (is.call(x[[2]][[2]])) {
-            if (any(grepl(x[[2]][[2]], pattern = ".xData"))) {# i.e., sim@.xData
+            if (any(grepl(x[[2]][[2]], pattern = ".xData"))) {# i.e., sim@.xData$.mods
               assigner <- FALSE
             } else {
             assigner <- TRUE # accessor on LHS like P(sim$a) <- "hi"
@@ -265,19 +265,19 @@ cantCodeCheckMessage <- ": line could not be checked "
   outputObjNames <- na.omit(sim@depends@dependencies[[k]]@outputObjects$objectName)
 
   # search for all sim$xx <-  or sim[[xxx]] <- in module code
-  simAssigns <- .findElementsInEnv(environment(), sim@.xData[[m]], type = "assign")
+  simAssigns <- .findElementsInEnv(environment(), sim@.xData$.mods[[m]], type = "assign")
   simAssigns <- simAssigns[!(simAssigns %in% ignoreObjectsAssign)]
 
   # search for all '<- sim$' or '<- sim[[xxx]]' in module code
-  simGets <- .findElementsInEnv(environment(), sim@.xData[[m]], type = "get")
+  simGets <- .findElementsInEnv(environment(), sim@.xData$.mods[[m]], type = "get")
   simGets <- simGets[!(simGets %in% ignoreObjectsGet)]
 
-  returnsSim <- .findElementsInEnv(environment(), sim@.xData[[m]], type = "returnSim")
+  returnsSim <- .findElementsInEnv(environment(), sim@.xData$.mods[[m]], type = "returnSim")
   returnsSim <- tapply(returnsSim, names(returnsSim), function(xx) any(xx == "sim"))
 
-  assignToSim <- .findElementsInEnv(environment(), sim@.xData[[m]], type = "assignToSim")
+  assignToSim <- .findElementsInEnv(environment(), sim@.xData$.mods[[m]], type = "assignToSim")
 
-  fg <- .findElementsInEnv(environment(), sim@.xData[[m]], type = "globals")
+  fg <- .findElementsInEnv(environment(), sim@.xData$.mods[[m]], type = "globals")
   hasConflicts <- fg[fg %in% conflictingFnsSimple]
 
   # Can't code check:
@@ -411,7 +411,7 @@ cantCodeCheckMessage <- ": line could not be checked "
   needInstall("codetools",
               messageStart = "Some code checking can't be done with codetools package: ")
   checkUsageMsg <- capture.output(
-    do.call(codetools::checkUsageEnv, args = append(list(env = sim@.xData[[m]]), checks))
+    do.call(codetools::checkUsageEnv, args = append(list(env = sim@.xData$.mods[[m]]), checks))
   )
   checkUsageMsg <- grep(checkUsageMsg, pattern = "doEvent.*: parameter",
                         invert = TRUE, value = TRUE)
@@ -519,9 +519,9 @@ cantCodeCheckMessage <- ": line could not be checked "
   }
 
   # search for conflicts in module function names with common problems, like quickPlot::Plot
-  clashingFuns <- names(sim@.xData[[m]])[names(sim@.xData[[m]]) %in% clashingFnsSimple]
+  clashingFuns <- names(sim@.xData$.mods[[m]])[names(sim@.xData$.mods[[m]]) %in% clashingFnsSimple]
   if (length(clashingFuns)) {
-    fnNames <- clashingFnsClean[clashingFnsSimple %in% names(sim@.xData[[m]])]
+    fnNames <- clashingFnsClean[clashingFnsSimple %in% names(sim@.xData$.mods[[m]])]
     verb <- .verb(clashingFuns)
     hadPrevMessage <- .parseMessage(m, "module functions", paste0(
             paste(clashingFuns, collapse = ", "), " ", verb,
@@ -638,7 +638,7 @@ cantCodeCheckMessage <- ": line could not be checked "
 
 .lineNumbersInSrcFile <- function(sim, module, namedTxt, pd) {
   if (!missing(sim)) {
-    pd <- sim@.xData[[module]][["._parsedData"]]
+    pd <- sim@.xData$.mods[[module]][["._parsedData"]]
   }
   lineNumbers <- lapply(seq(namedTxt), function(patternIndex) {
     patt <- gsub("\\(", "\\\\(", namedTxt[patternIndex])
