@@ -17,14 +17,12 @@ utils::globalVariables(c("newQuantity", "quantityAdj", "quantityAdj2"))
   }
 }
 
+
 ################################################################################
 #' Update elements of a named list with elements of a second named list
 #'
-#' Merge two named list based on their named entries. Where
-#' any element matches in both lists, the value from the
-#' second list is used in the updated list.
-#' Subelements are not examined and are simply replaced. If one list is empty, then
-#' it returns the other one, unchanged.
+#' Being deprecated. Use \code{\link[utils]{modifyList}} (which can not handle NULL) or
+#' \code{\link[Require]{modifyList2}} for case with >2 lists and can handle NULL lists.
 #'
 #' @param x   a named list
 #' @param y   a named list
@@ -35,6 +33,7 @@ utils::globalVariables(c("newQuantity", "quantityAdj", "quantityAdj2"))
 #'
 #' @author Alex Chubaty
 #' @export
+#' @importFrom utils modifyList
 #' @rdname updateList
 #'
 #' @examples
@@ -43,56 +42,19 @@ utils::globalVariables(c("newQuantity", "quantityAdj", "quantityAdj2"))
 #' updateList(L1, L2)
 #'
 #' updateList(L1, NULL)
+#' updateList(L1)
+#' updateList(y = L2)
 #' updateList(NULL, L2)
 #' updateList(NULL, NULL) # should return empty list
 #'
-setGeneric("updateList", function(x, y) {
-  standardGeneric("updateList")
-})
+updateList <- function(x, y) {
+  if (missing(x)) x <- list()
+  if (missing(y)) y <- list()
+  if (is.null(y)) y <- list()
+  if (is.null(x)) x <- list()
+  modifyList(x = x, val = y)
+}
 
-#' @rdname updateList
-setMethod("updateList",
-          signature = c("list", "list"),
-          definition = function(x, y) {
-            if (any(is.null(names(x)), is.null(names(y)))) {
-              # If one of the lists is empty, then just return the other, unchanged
-              if (length(y) == 0) return(x)
-              if (length(x) == 0) return(y)
-              stop("All elements in lists x,y must be named.")
-            } else {
-              x[names(y)] <- y
-              return(x[order(names(x))])
-            }
-})
-
-#' @rdname updateList
-setMethod("updateList",
-          signature = c("NULL", "list"),
-          definition = function(x, y) {
-            if (is.null(names(y))) {
-              if (length(y) == 0) return(x)
-              stop("All elements in list y must be named.")
-            }
-            return(y[order(names(y))])
-})
-
-#' @rdname updateList
-setMethod("updateList",
-          signature = c("list", "NULL"),
-          definition = function(x, y) {
-            if (is.null(names(x))) {
-              if (length(x) == 0) return(x)
-              stop("All elements in list x must be named.")
-            }
-            return(x[order(names(x))])
-})
-
-#' @rdname updateList
-setMethod("updateList",
-          signature = c("NULL", "NULL"),
-          definition = function(x, y) {
-            return(list())
-})
 
 ################################################################################
 #' Add a module to a \code{moduleList}
@@ -137,132 +99,7 @@ setMethod("append_attr",
             return(out[!dups])
 })
 
-################################################################################
-#' Load packages.
-#'
-#' Load and optionally install additional packages.
-#'
-#' @param packageList A list of character strings specifying
-#' the names of packages to be loaded.
-#'
-#' @param install Logical flag. If required packages are not
-#' already installed, should they be installed?
-#'
-#' @param quiet Logical flag. Should the final "packages loaded"
-#' message be suppressed?
-#'
-#' @return Specified packages are loaded and attached using \code{require()},
-#'         invisibly returning a logical vector of successes.
-#'
-#' @seealso \code{\link{require}}.
-#'
-#' @export
-#' @rdname loadPackages
-#' @importFrom utils install.packages installed.packages
-#'
-#' @author Alex Chubaty
-#'
-#' @examples
-#' \dontrun{
-#'   pkgs <- list("raster", "lme4")
-#'   loadPackages(pkgs) # loads packages if installed
-#'   loadPackages(pkgs, install = TRUE) # loads packages after installation (if needed)
-#' }
-#'
-setGeneric("loadPackages", function(packageList, install = FALSE, quiet = TRUE) {
-  standardGeneric("loadPackages")
-})
 
-#' @rdname loadPackages
-setMethod(
-  "loadPackages",
-  signature = "character",
-  definition = function(packageList, install, quiet) {
-    packageList <- na.omit(packageList) %>% as.character()
-    if (length(packageList)) {
-      if (install) {
-        repos <- getOption("repos")
-        if (is.null(repos) | any(repos == "")) {
-          repos <- "https://cran.rstudio.com"
-        }
-        installed <- unname(installed.packages()[, "Package"])
-        toInstall <- packageList[packageList %in% installed]
-        install.packages(toInstall, repos = repos)
-      }
-
-      loaded <- suppressMessages(sapply(packageList, require, character.only = TRUE,
-                                        quiet = TRUE, warn.conflicts = FALSE))
-      if (any(!loaded)) {
-        alreadyLoaded <- unlist(lapply(packageList[!loaded], isNamespaceLoaded))
-        if (!all(alreadyLoaded)) {
-          stop("Some packages required for the simulation are not installed:\n",
-             "    ", paste(names(loaded[-which(loaded)]), collapse = "\n    "))
-        } else {
-          message("Older version(s) of ",
-                  paste(collapse = ", ", packageList[!loaded]), " already loaded")
-        }
-      }
-
-      if (!quiet) {
-        message(paste("Loaded", length(which(loaded == TRUE)), "of",
-                      length(packageList), "packages.", sep = " "))
-      }
-    } else {
-      loaded <- character(0)
-    }
-    return(invisible(loaded))
-})
-
-#' @rdname loadPackages
-setMethod("loadPackages",
-          signature = "list",
-          definition = function(packageList, install, quiet) {
-            loadPackages(unlist(packageList), install, quiet)
-})
-
-#' @rdname loadPackages
-setMethod("loadPackages",
-          signature = "NULL",
-          definition = function(packageList, install, quiet) {
-            return(invisible(character(0)))
-})
-
-################################################################################
-#' Convert numeric to character with padding
-#'
-#' This will pad floating point numbers, right or left. For integers, either class
-#' integer or functionally integer (e.g., 1.0), it will not pad right of the decimal.
-#' For more specific control or to get exact padding right and left of decimal,
-#' try the \code{stringi} package. It will also not do any rounding. See examples.
-#'
-#' @param x numeric. Number to be converted to character with padding
-#'
-#' @param padL numeric. Desired number of digits on left side of decimal.
-#'              If not enough, \code{pad} will be used to pad.
-#'
-#' @param padR numeric. Desired number of digits on right side of decimal.
-#'              If not enough, \code{pad} will be used to pad.
-#'
-#' @param pad character to use as padding (\code{nchar(pad) == 1} must be \code{TRUE}).
-#'
-#' @return Character string representing the filename.
-#'
-#' @author Eliot McIntire and Alex Chubaty
-#' @export
-#' @importFrom fpCompare %==%
-#' @rdname paddedFloatToChar
-#'
-#' @examples
-#' paddedFloatToChar(1.25)
-#' paddedFloatToChar(1.25, padL = 3, padR = 5)
-#' paddedFloatToChar(1.25, padL = 3, padR = 1) # no rounding, so keeps 2 right of decimal
-paddedFloatToChar <- function(x, padL = ceiling(log10(x + 1)), padR = 3, pad = "0") {
-  xf <- x %% 1
-  numDecimals <- nchar(gsub("(.*)(\\.)|([0]*$)","",xf))
-  newPadR <- ifelse(xf %==% 0, 0, pmax(numDecimals, padR))
-  xFCEnd <- sprintf(paste0("%0", padL+newPadR+1*(newPadR > 0),".", newPadR, "f"), x)
-  return(xFCEnd)
-}
 
 ###############################################################################
 #' Generate random strings
@@ -642,7 +479,6 @@ Paths <- .paths()
 #' @rdname setPaths
 #' @importFrom raster tmpDir
 #' @importFrom Require checkPath
-#' @importFrom R.utils getOption
 #' @param silent Logical. Should the messaging occur.
 setPaths <- function(cachePath, inputPath, modulePath, outputPath, rasterPath, silent = FALSE) {
   defaults <- list(
@@ -719,3 +555,24 @@ setPaths <- function(cachePath, inputPath, modulePath, outputPath, rasterPath, s
   lapply(.paths(), checkPath, create = TRUE)
   return(invisible(originalPaths))
 }
+
+#' Simple wrapper around \code{data.table::rbindlist}
+#'
+#' This simply sets defaults to \code{fill = TRUE}, and
+#' \code{use.names = TRUE}
+#'
+#' @param ... 1 or more \code{data.frame}, \code{data.table}, or \code{list} objects
+#' @export
+bindrows <- function(...) {
+  # Deal with things like "trailing commas"
+  rws <- try(list(...), silent = TRUE)
+  if (any(grepl("argument is missing|bind_rows", rws))) {
+    ll <- as.list(match.call(expand.dots = TRUE))
+    nonEmpties <- unlist(lapply(ll, function(x) any(nchar(x) > 0)))
+    eval(as.call(ll[nonEmpties]))
+  } else if (is(rws, "try-error")) {
+    stop(rws)
+  } else {
+    rbindlist(rws, fill = TRUE, use.names = TRUE)
+  }
+}
